@@ -1,3 +1,7 @@
+// Bug 1506 P1-3: This code is mostly hackish remnants of session store
+// support. There are a couple of observer events that *might* be worth
+// listening to. Search for 1506 in the code.
+
 /*************************************************************************
  * Crash observer (JavaScript XPCOM component)
  *
@@ -50,7 +54,17 @@ function CrashObserver() {
         this.is_ff4 = false;
     }
 
+    try {
+      var test = this._prefs.getCharPref("torbrowser.version");
+      this.is_tbb = true;
+      this.logger.log(3, "This is a Tor Browser's XPCOM");
+    } catch(e) {
+      this.logger.log(3, "This is not a Tor Browser's XPCOM");
+    }
+
     if (this.is_ff4) {
+      // Bug 1506 P2/P3: You probably want to register this observer to clean up
+      // prefs if you're going to support using normal firefox. 
       Components.utils.import("resource://gre/modules/AddonManager.jsm");
       this.onEnabling = this.onOperationCancelled;
       this.onDisabling = this.onUninstalling;
@@ -70,6 +84,8 @@ CrashObserver.prototype = {
     // us somehow, we will leave the browser in a sorry state... Let's hope they
     // have the sense not to uninstall addons after an improper shutdown/crash
     // (or at least give us this event again in that case).
+    // Bug 1506 P2/P3: You probably want to register this observer to clean up
+    // prefs if you're going to support using normal firefox. 
     onUninstalling: function(addon, needsRestart) {
       if (addon.id.toUpperCase() == TORBUTTON_EXTENSION_UUID) {
         this._uninstall = true;
@@ -85,6 +101,8 @@ CrashObserver.prototype = {
     // This is done in the constructor. JS doesn't allow this...
     //onDisabling: this.onUninstalling,
 
+    // Bug 1506 P2/P3: You probably want to register this observer to clean up
+    // prefs if you're going to support using normal firefox. 
     onOperationCancelled: function(addon) {
       if (addon.id.toUpperCase() == TORBUTTON_EXTENSION_UUID) {
          this.logger.log(4, "Uninstall of Torbutton canceled. Hurray!");
@@ -92,11 +110,59 @@ CrashObserver.prototype = {
       }
     },
 
-    // This is done in the constructor. JS doesn't allow this...
-    //onEnabling: this.onOperationCancelled,
+    // Bug 6803: We need to get the env vars early due to
+    // some weird proxy caching code that showed up in FF15.
+    // Otherwise, homepage domain loads fail forever.
+    getProxySettings: function() {
+      // Bug 1506: Still want to get these env vars
+      var environ = Components.classes["@mozilla.org/process/environment;1"]
+                 .getService(Components.interfaces.nsIEnvironment);
+
+      if (environ.exists("TOR_SOCKS_PORT")) {
+        this.logger.log(3, "Resetting socks port to "+environ.get("TOR_SOCKS_PORT"));
+        this._prefs.setIntPref('extensions.torbutton.socks_port',
+                parseInt(environ.get("TOR_SOCKS_PORT")));
+        if (this.is_tbb) {
+            this._prefs.setIntPref('network.proxy.socks_port', parseInt(environ.get("TOR_SOCKS_PORT")));
+
+            // XXX: Hack for TBB people who alternate between transproxy and non
+            this._prefs.setCharPref('extensions.torbutton.settings_method', 'recommended');
+            this._prefs.setBoolPref('extensions.torbutton.saved.transparentTor', false);
+            this._prefs.setBoolPref('network.proxy.socks_remote_dns', true);
+            this._prefs.setIntPref('network.proxy.type', 1);
+        }
+      } else if (this._prefs.getCharPref('extensions.torbutton.settings_method') == 'recommended') {
+        this._prefs.setIntPref('extensions.torbutton.socks_port', 9050);
+      }
+
+      if (environ.exists("TOR_SOCKS_HOST")) {
+        this._prefs.setCharPref('extensions.torbutton.socks_host', environ.get("TOR_SOCKS_HOST"));
+        if (this.is_tbb) {
+            this._prefs.setCharPref('network.proxy.socks', environ.get("TOR_SOCKS_HOST"));
+        }
+      } else if (this._prefs.getCharPref('extensions.torbutton.settings_method') == 'recommended') {
+        this._prefs.setCharPref('extensions.torbutton.socks_host', '127.0.0.1');
+      }
+
+      if (environ.exists("TOR_TRANSPROXY")) {
+        this.logger.log(3, "Resetting Tor settings to transproxy");
+        this._prefs.setCharPref('extensions.torbutton.settings_method', 'transparent');
+        this._prefs.setBoolPref('extensions.torbutton.saved.transparentTor', true);
+        this._prefs.setIntPref('extensions.torbutton.socks_port', 0);
+        this._prefs.setCharPref('extensions.torbutton.socks_host', "");
+        if (this.is_tbb) {
+            this._prefs.setBoolPref('network.proxy.socks_remote_dns', false);
+            this._prefs.setIntPref('network.proxy.type', 0);
+            this._prefs.setIntPref('network.proxy.socks_port', 0);
+            this._prefs.setCharPref('network.proxy.socks', "");
+        }
+      }
+    },
 
     observe: function(subject, topic, data) {
       if(topic == "profile-after-change") {
+        // Bug 1506 P1: We listen to these prefs as signals for startup,
+        // but only for hackish reasons.
         if(this._prefs.getBoolPref("extensions.torbutton.fresh_install")) {
           this._prefs.setBoolPref("extensions.torbutton.normal_exit", true);
         }
@@ -107,6 +173,8 @@ CrashObserver.prototype = {
           this._prefs.setBoolPref("extensions.torbutton.crashed", true);
         }
         this._prefs.setBoolPref("extensions.torbutton.normal_exit", false);
+
+        this.getProxySettings();
       } else if (topic == "em-action-requested") {
         this.logger.log(3, "Uninstall action requested..");
         // http://xulsolutions.blogspot.com/2006/07/creating-uninstall-script-for.html
@@ -122,6 +190,8 @@ CrashObserver.prototype = {
           }
         }
       } else if (topic == "quit-application-granted") {
+        // Bug 1506 P2/P3: You probably want to register this observer to clean up
+        // prefs if you're going to support using normal firefox. 
         this.logger.log(3, "Got firefox quit event.");
         var chrome = null;
         try {
