@@ -22,7 +22,7 @@ pref("extensions.torbutton.gopher_port",0);
 pref("extensions.torbutton.socks_host","");
 pref("extensions.torbutton.socks_port",0);
 pref("extensions.torbutton.socks_version",5);
-pref("extensions.torbutton.locked_mode",false);
+pref("extensions.torbutton.locked_mode",true);
 pref("extensions.torbutton.test_url","https://check.torproject.org/?TorButton=true");
 pref("extensions.torbutton.test_failed",false);
 pref("extensions.torbutton.no_proxies_on","127.0.0.1");
@@ -136,7 +136,7 @@ pref("extensions.torbutton.no_search",true);
 pref("extensions.torbutton.set_uagent",true);
 pref("extensions.torbutton.notor_sessionstore",true);
 pref("extensions.torbutton.nonontor_sessionstore",false);
-pref("extensions.torbutton.restore_tor",false); 
+pref("extensions.torbutton.restore_tor",true); 
 pref("extensions.torbutton.reload_crashed_jar",true); 
 pref("extensions.torbutton.spoof_english",true);
 pref("extensions.torbutton.spoof_charset",'iso-8859-1,*,utf-8');
@@ -193,13 +193,13 @@ pref("extensions.torbutton.regen_google_cookies", false);
 pref("extensions.torbutton.xfer_google_cookies", true);
 
 // Google redirect prefs
-pref("extensions.torbutton.google_redir_url", 5);
+pref("extensions.torbutton.google_redir_url", 4);
 pref("extensions.torbutton.dodge_google_captcha", true);
 pref("extensions.torbutton.asked_google_captcha", false);
 pref("extensions.torbutton.redir_url.1", "https://www.ixquick.com/do/metasearch.pl?query=");
 pref("extensions.torbutton.redir_url.2", "http://www.bing.com/search?q=");
 pref("extensions.torbutton.redir_url.3", "http://search.yahoo.com/search?p=");
-pref("extensions.torbutton.redir_url.4", "https://ssl.scroogle.org/cgi-bin/nbbwssl.cgi?Gw=");
+pref("extensions.torbutton.redir_url.4", "https://www.startpage.com/do/search?query=");
 pref("extensions.torbutton.redir_url.5", "https://duckduckgo.com/?q=");
 pref("extensions.torbutton.fix_google_srch", true);
 
@@ -209,7 +209,8 @@ pref("extensions.torbutton.appversion_override","5.0 (Windows)");
 pref("extensions.torbutton.platform_override","Win32");
 pref("extensions.torbutton.oscpu_override", "Windows NT 6.1");
 
-pref("extensions.torbutton.useragent_override", "Mozilla/5.0 (Windows NT 6.1; rv:5.0) Gecko/20100101 Firefox/5.0");
+pref("extensions.torbutton.useragent_override",
+     "Mozilla/5.0 (Windows NT 6.1; rv:10.0) Gecko/20100101 Firefox/10.0");
 
 pref("extensions.torbutton.productsub_override","20100101");
 pref("extensions.torbutton.buildID_override","0");
@@ -219,3 +220,4 @@ pref("extensions.torbutton.useragent_vendorSub","");
 pref("extensions.torbutton.safecache",1); // 0=always, 1=during tor, 2=never
 pref("extensions.torbutton.dual_key_cookies",false);
 pref("extensions.torbutton.cookie_js_allow", true);
+pref("extensions.torbutton.prompt_torbrowser", true);
